@@ -49,9 +49,9 @@
 #.mean.gram <- function(X) { (t(X) %*% X) / dim(X)[1] }
 
 # quadratic forms
-.qform <- function(bread,meat) {
+.qform <- function(bread,meat) { # nocov start
 	return(t(bread) %*% (meat %*% bread))
-}
+} # nocov end
 # and 'outer' 
 .qoform <- function(bread,meat) {
 	return(bread %*% (meat %*% t(bread)))
@@ -99,12 +99,12 @@
 }
 
 # for T^2: 
-.annualize2 <- function(T2, ope) {
+.annualize2 <- function(T2, ope) { # nocov start
   return(T2 * ope)  
-}
-.deannualize2 <- function(T2.pa, ope) {
+} # nocov end
+.deannualize2 <- function(T2.pa, ope) { # nocov start
   return(T2.pa / ope)
-}
+} # nocov end
 #UNFOLD
 
 # conversions
